@@ -26,6 +26,9 @@ var bashInit string
 //go:embed init/omp.zsh
 var zshInit string
 
+//go:embed init/omp.lua
+var cmdInit string
+
 const (
 	noExe       = "echo \"Unable to find Oh My Posh executable\""
 	zsh         = "zsh"
@@ -33,6 +36,7 @@ const (
 	pwsh        = "pwsh"
 	fish        = "fish"
 	powershell5 = "powershell"
+	winCMD      = "cmd"
 	plain       = "shell"
 )
 
@@ -56,6 +60,7 @@ type args struct {
 	Author         *string
 	CursorPadding  *int
 	RPromptOffset  *int
+	RPrompt        *bool
 	BGColor        *string
 	StackCount     *int
 	Command        *string
@@ -141,6 +146,10 @@ func main() {
 			"rprompt-offset",
 			40,
 			"Offset the right prompt with x when using --export-img"),
+		RPrompt: flag.Bool(
+			"rprompt",
+			false,
+			"Only print the rprompt block"),
 		BGColor: flag.String(
 			"bg-color",
 			"#151515",
@@ -230,6 +239,10 @@ func main() {
 		fmt.Print(engine.renderTooltip(*args.Command))
 		return
 	}
+	if *args.RPrompt {
+		fmt.Print(engine.renderRPrompt())
+		return
+	}
 	prompt := engine.render()
 	if !*args.ExportPNG {
 		fmt.Print(prompt)
@@ -275,7 +288,7 @@ func initShell(shell, configFile string) string {
 	switch shell {
 	case pwsh:
 		return fmt.Sprintf("(@(&\"%s\" --print-init --shell=pwsh --config=\"%s\") -join \"`n\") | Invoke-Expression", executable, configFile)
-	case zsh, bash, fish:
+	case zsh, bash, fish, winCMD:
 		return printShellInit(shell, configFile)
 	default:
 		return fmt.Sprintf("echo \"No initialization script available for %s\"", shell)
@@ -296,6 +309,8 @@ func printShellInit(shell, configFile string) string {
 		return getShellInitScript(executable, configFile, bashInit)
 	case fish:
 		return getShellInitScript(executable, configFile, fishInit)
+	case winCMD:
+		return getShellInitScript(executable, configFile, cmdInit)
 	default:
 		return fmt.Sprintf("echo \"No initialization script available for %s\"", shell)
 	}
