@@ -15,7 +15,8 @@ type terraformArgs struct {
 func bootStrapTerraformTest(args *terraformArgs) *terraform {
 	env := new(MockedEnvironment)
 	env.On("hasCommand", "terraform").Return(args.hasTfCommand)
-	env.On("hasFolder", ".terraform").Return(args.hasTfFolder)
+	env.On("hasFolder", "/.terraform").Return(args.hasTfFolder)
+	env.On("getcwd", nil).Return("")
 	env.On("runCommand", "terraform", []string{"workspace", "show"}).Return(args.workspaceName, nil)
 	k := &terraform{
 		env:   env,
