@@ -84,6 +84,7 @@ func TestShouldIncludeFolder(t *testing.T) {
 		env := new(MockedEnvironment)
 		env.On("getRuntimeGOOS", nil).Return(linuxPlatform)
 		env.On("homeDir", nil).Return("")
+		env.On("getcwd", nil).Return(cwd)
 		segment := &Segment{
 			Properties: map[Property]interface{}{
 				IncludeFolders: tc.IncludeFolders,
@@ -91,7 +92,7 @@ func TestShouldIncludeFolder(t *testing.T) {
 			},
 			env: env,
 		}
-		got := segment.shouldIncludeFolder(cwd)
+		got := segment.shouldIncludeFolder()
 		assert.Equal(t, tc.Expected, got, tc.Case)
 	}
 }
@@ -100,6 +101,7 @@ func TestShouldIncludeFolderRegexInverted(t *testing.T) {
 	env := new(MockedEnvironment)
 	env.On("getRuntimeGOOS", nil).Return(linuxPlatform)
 	env.On("homeDir", nil).Return("")
+	env.On("getcwd", nil).Return(cwd)
 	segment := &Segment{
 		Properties: map[Property]interface{}{
 			ExcludeFolders: []string{"(?!Projects[\\/]).*"},
@@ -113,13 +115,14 @@ func TestShouldIncludeFolderRegexInverted(t *testing.T) {
 			assert.Equal(t, "regexp: Compile(`^(?!Projects[\\/]).*$`): error parsing regexp: invalid or unsupported Perl syntax: `(?!`", err)
 		}
 	}()
-	segment.shouldIncludeFolder(cwd)
+	segment.shouldIncludeFolder()
 }
 
 func TestShouldIncludeFolderRegexInvertedNonEscaped(t *testing.T) {
 	env := new(MockedEnvironment)
 	env.On("getRuntimeGOOS", nil).Return(linuxPlatform)
 	env.On("homeDir", nil).Return("")
+	env.On("getcwd", nil).Return(cwd)
 	segment := &Segment{
 		Properties: map[Property]interface{}{
 			ExcludeFolders: []string{"(?!Projects/).*"},
@@ -133,7 +136,7 @@ func TestShouldIncludeFolderRegexInvertedNonEscaped(t *testing.T) {
 			assert.Equal(t, "regexp: Compile(`^(?!Projects/).*$`): error parsing regexp: invalid or unsupported Perl syntax: `(?!`", err)
 		}
 	}()
-	segment.shouldIncludeFolder(cwd)
+	segment.shouldIncludeFolder()
 }
 
 func TestGetColors(t *testing.T) {
@@ -208,39 +211,3 @@ func TestGetColors(t *testing.T) {
 		assert.Equal(t, tc.ExpectedColor, color, tc.Case)
 	}
 }
-
-func TestCwdMatchesOneOf(t *testing.T) {
-	cases := []struct {
-		GOOS     string
-		HomeDir  string
-		Cwd      string
-		Pattern  string
-		Expected bool
-	}{
-		{GOOS: linuxPlatform, HomeDir: "/home/bill", Cwd: "/home/bill", Pattern: "/home/bill", Expected: true},
-		{GOOS: linuxPlatform, HomeDir: "/home/bill", Cwd: "/home/bill/foo", Pattern: "~/foo", Expected: true},
-		{GOOS: linuxPlatform, HomeDir: "/home/bill", Cwd: "/home/bill/foo", Pattern: "~/Foo", Expected: false},
-		{GOOS: linuxPlatform, HomeDir: "/home/bill", Cwd: "/home/bill/foo", Pattern: "~\\\\foo", Expected: true},
-		{GOOS: linuxPlatform, HomeDir: "/home/bill", Cwd: "/home/bill/foo/bar", Pattern: "~/fo.*", Expected: true},
-		{GOOS: linuxPlatform, HomeDir: "/home/bill", Cwd: "/home/bill/foo", Pattern: "~/fo\\w", Expected: true},
-		{GOOS: windowsPlatform, HomeDir: "C:\\Users\\Bill", Cwd: "C:\\Users\\Bill", Pattern: "C:\\\\Users\\\\Bill", Expected: true},
-		{GOOS: windowsPlatform, HomeDir: "C:\\Users\\Bill", Cwd: "C:\\Users\\Bill", Pattern: "C:/Users/Bill", Expected: true},
-		{GOOS: windowsPlatform, HomeDir: "C:\\Users\\Bill", Cwd: "C:\\Users\\Bill", Pattern: "c:/users/bill", Expected: true},
-		{GOOS: windowsPlatform, HomeDir: "C:\\Users\\Bill", Cwd: "C:\\Users\\Bill", Pattern: "~", Expected: true},
-		{GOOS: windowsPlatform, HomeDir: "C:\\Users\\Bill", Cwd: "C:\\Users\\Bill\\Foo", Pattern: "~/Foo", Expected: true},
-		{GOOS: windowsPlatform, HomeDir: "C:\\Users\\Bill", Cwd: "C:\\Users\\Bill\\Foo", Pattern: "~/foo", Expected: true},
-		{GOOS: windowsPlatform, HomeDir: "C:\\Users\\Bill", Cwd: "C:\\Users\\Bill\\Foo\\Bar", Pattern: "~/fo.*", Expected: true},
-		{GOOS: windowsPlatform, HomeDir: "C:\\Users\\Bill", Cwd: "C:\\Users\\Bill\\Foo", Pattern: "~/fo\\w", Expected: true},
-	}
-
-	for _, tc := range cases {
-		env := new(MockedEnvironment)
-		env.On("getRuntimeGOOS", nil).Return(tc.GOOS)
-		env.On("homeDir", nil).Return(tc.HomeDir)
-		segment := &Segment{
-			env: env,
-		}
-		got := segment.cwdMatchesOneOf(tc.Cwd, []string{tc.Pattern})
-		assert.Equal(t, tc.Expected, got)
-	}
-}
